pitchtools.ObjectSegment
========================

.. abjad-lineage:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment

.. autoclass:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.count
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.index
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__getslice__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__mul__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__rmul__
   :noindex:
